@@ -1,3 +1,5 @@
+#include <QDesktopServices>
+#include <QUrl>
 #include "symfonieaboutdialog.h"
 #include "ui_symfonieaboutdialog.h"
 
@@ -7,14 +9,21 @@ SymfonieAboutDialog::SymfonieAboutDialog(QWidget *parent) :
 {
     ui->setupUi(this);
      this->setAttribute(Qt::WA_DeleteOnClose, true);
-    this->setWindowTitle(tr("About This Application"));
+    this->setWindowTitle(tr("About symfonie"));
+    connect(this->ui->btnHomePage, SIGNAL(released()), this, SLOT(openHomeUrlSlot()));
 }
 
+
+
 SymfonieAboutDialog::~SymfonieAboutDialog()
 {
     delete ui;
 }
 
+void SymfonieAboutDialog::openHomeUrlSlot(){
+     QDesktopServices::openUrl(QUrl("http://thecodecentral.com", QUrl::TolerantMode));
+}
+
 void SymfonieAboutDialog::changeEvent(QEvent *e)
 {
     QDialog::changeEvent(e);
@@ -27,3 +36,4 @@ void SymfonieAboutDialog::changeEvent(QEvent *e)
         break;
     }
 }
+
