@@ -597,7 +597,7 @@ void SymfonieMediaPlayer::aboutToFinishSlot(){
 }
 
 
-void SymfonieMediaPlayer::currentSourceChangedSlot ( const Phonon::MediaSource &newSource ) {
+void SymfonieMediaPlayer::currentSourceChangedSlot ( const Phonon::MediaSource &/*newSource*/ ) {
     this->currentPlaybackIndex = this->queuedIndex;
 }
 
